pub struct Scanner { /* private fields */ }Expand description
Scanner for discovering audiobook folders in a directory tree
Implementations
Sourceimpl Scanner
impl Scanner
Sourcepub fn with_cover_filenames(cover_filenames: Vec<String>) -> Self
pub fn with_cover_filenames(cover_filenames: Vec<String>) -> Self
Create scanner with custom cover filenames
Sourcepub fn from_config(config: &Config) -> Self
pub fn from_config(config: &Config) -> Self
Create scanner from config
Sourcepub fn scan_directory(&self, root: &Path) -> Result<Vec<BookFolder>>
pub fn scan_directory(&self, root: &Path) -> Result<Vec<BookFolder>>
Scan a directory for audiobook folders
Sourcepub fn scan_single_directory(&self, path: &Path) -> Result<BookFolder>
pub fn scan_single_directory(&self, path: &Path) -> Result<BookFolder>
Scan a single directory as an audiobook folder (for auto-detect mode)