pub struct QualityProfile {
pub bitrate: u32,
pub sample_rate: u32,
pub channels: u8,
pub codec: String,
pub duration: f64,
}Expand description
Audio quality profile with bitrate, sample rate, channels, and codec
Fields
bitrate: u32Bitrate in kbps
sample_rate: u32Sample rate in Hz
channels: u8Number of channels (1=mono, 2=stereo)
codec: StringAudio codec (e.g., “mp3”, “aac”)
duration: f64Duration in seconds
Implementations
Sourceimpl QualityProfile
impl QualityProfile
Sourcepub fn new(
bitrate: u32,
sample_rate: u32,
channels: u8,
codec: String,
duration: f64,
) -> Result<Self>
pub fn new( bitrate: u32, sample_rate: u32, channels: u8, codec: String, duration: f64, ) -> Result<Self>
Create a new quality profile
Sourcepub fn is_better_than(
&self,
other: &QualityProfile,
prefer_stereo: bool,
) -> bool
pub fn is_better_than( &self, other: &QualityProfile, prefer_stereo: bool, ) -> bool
Compare quality profiles to determine which is better
Sourcepub fn is_compatible_for_concat(&self, other: &QualityProfile) -> bool
pub fn is_compatible_for_concat(&self, other: &QualityProfile) -> bool
Check if two profiles can be concatenated without re-encoding
Sourcepub fn to_aac_equivalent(&self) -> QualityProfile
pub fn to_aac_equivalent(&self) -> QualityProfile
Convert to AAC profile with equivalent or better quality
Sourcepub fn from_preset(
preset: &str,
source: &QualityProfile,
) -> Option<QualityProfile>
pub fn from_preset( preset: &str, source: &QualityProfile, ) -> Option<QualityProfile>
Create a quality profile from a preset Returns None for “source” preset (auto-detect from source files)
Sourcepub fn apply_preset(&self, preset: Option<&str>) -> QualityProfile
pub fn apply_preset(&self, preset: Option<&str>) -> QualityProfile
Apply quality preset override if specified